@@ -1,4 +1,4 @@
-# Copyright 2018-2019 Descartes Labs.
+# Copyright 2018-2020 Descartes Labs.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -70,13 +70,12 @@ class TestAuth(unittest.TestCase):
         warnings.resetwarnings()
 
     def test_auth_client_refresh_match(self):
-        with warnings.catch_warnings(record=True) as w:
+        with warnings.catch_warnings(record=True):
             auth = Auth(
                 client_id="client_id",
                 client_secret="secret",
                 refresh_token="mismatched_refresh_token",
             )
-            assert 1 == len(w)
             assert "mismatched_refresh_token" == auth.refresh_token
             assert "mismatched_refresh_token" == auth.client_secret
 
@@ -261,8 +260,7 @@ class TestAuth(unittest.TestCase):
             # when refresh_token and client_secret do not match,
             # the Auth implementation sets both to the value of
             # refresh_token
-            assert auth.client_secret == \
-                environ.get("DESCARTESLABS_REFRESH_TOKEN")
+            assert auth.client_secret == environ.get("DESCARTESLABS_REFRESH_TOKEN")
             assert auth.client_id == environ.get("DESCARTESLABS_CLIENT_ID")
 
         # remove the namespaced ones, except the refresh token because
